@@ -125,7 +125,7 @@ public:
     // setup widget contents
     ui->m_nameEdit->setText(m_schedule.name());
 
-    ui->m_frequencyEdit->setCurrentItem((int)m_schedule.occurrencePeriod());
+    ui->m_frequencyEdit->setCurrentItem((int)m_schedule.occurrence());
     if (ui->m_frequencyEdit->currentItem() == Schedule::Occurrence::Any)
       ui->m_frequencyEdit->setCurrentItem((int)Schedule::Occurrence::Monthly);
     q->slotFrequencyChanged((int)ui->m_frequencyEdit->currentItem());
@@ -263,7 +263,7 @@ TransactionEditor* KEditScheduleDlg::startEdit()
 
   if (editor) {
     editor->setScheduleInfo(d->ui->m_nameEdit->text());
-    connect(editor, &TransactionEditor::transactionDataSufficient, d->ui->buttonBox->button(QDialogButtonBox::Ok), &QWidget::setEnabled);
+    connect(editor, &TransactionEditor::transactionDataSufficient, d->m_requiredFields, &KMandatoryFieldGroup::setExternalMandatoryState);
     connect(editor, &TransactionEditor::escapePressed, d->ui->buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::animateClick);
     connect(editor, &TransactionEditor::returnPressed, d->ui->buttonBox->button(QDialogButtonBox::Ok), &QAbstractButton::animateClick);
 
@@ -484,9 +484,11 @@ void KEditScheduleDlg::newSchedule(const MyMoneyTransaction& _t, eMyMoney::Sched
       schedule.setNextDueDate(schedule.nextPayment(t.postDate()));
   }
 
-  QPointer<KEditScheduleDlg> dlg = new KEditScheduleDlg(schedule, nullptr);
-  QPointer<TransactionEditor> transactionEditor = dlg->startEdit();
-  if (transactionEditor) {
+  bool committed;
+  do {
+    committed = true;
+    QPointer<KEditScheduleDlg> dlg = new KEditScheduleDlg(schedule, nullptr);
+    QPointer<TransactionEditor> transactionEditor = dlg->startEdit();
     KMyMoneyMVCCombo::setSubstringSearchForChildren(dlg, !KMyMoneySettings::stringMatchFromStart());
     if (dlg->exec() == QDialog::Accepted && dlg != 0) {
       MyMoneyFileTransaction ft;
@@ -497,11 +499,12 @@ void KEditScheduleDlg::newSchedule(const MyMoneyTransaction& _t, eMyMoney::Sched
 
       } catch (const MyMoneyException &e) {
         KMessageBox::error(nullptr, i18n("Unable to add scheduled transaction: %1", QString::fromLatin1(e.what())), i18n("Add scheduled transaction"));
+        committed = false;
       }
     }
-  }
-  delete transactionEditor;
-  delete dlg;
+    delete transactionEditor;
+    delete dlg;
+  } while(!committed);
 }
 
 void KEditScheduleDlg::editSchedule(const MyMoneySchedule& inputSchedule)
