@@ -1,19 +1,20 @@
-/***************************************************************************
-                          kfindtransactiondlg.h
-                             -------------------
-    copyright            : (C) 2003 by Thomas Baumgart
-    email                : ipwizard@users.sourceforge.net
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2002-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef KFINDTRANSACTIONDLG_H
 #define KFINDTRANSACTIONDLG_H
@@ -78,20 +79,6 @@ protected Q_SLOTS:
     */
   virtual void slotShowHelp();
 
-  void slotUpdateSelections();
-
-  virtual void slotAmountSelected();
-  virtual void slotAmountRangeSelected();
-
-  virtual void slotSelectAllPayees();
-  virtual void slotDeselectAllPayees();
-
-  virtual void slotSelectAllTags();
-  virtual void slotDeselectAllTags();
-
-  virtual void slotNrSelected();
-  virtual void slotNrRangeSelected();
-
   void slotRefreshView();
 
   /**
