@@ -365,7 +365,7 @@ void StdTransactionEditor::loadEditWidgets(eRegister::Action action)
 
   // if an account is specified then remove it from the widget so that the user
   // cannot create a transfer with from and to account being the same account
-  if (!d->m_account.id().isEmpty())
+  if (category && !d->m_account.id().isEmpty())
     category->selector()->removeItem(d->m_account.id());
 
   //  also show memo text if isMultiSelection()
@@ -411,7 +411,9 @@ void StdTransactionEditor::loadEditWidgets(eRegister::Action action)
 
     d->m_splits.clear();
     if (d->m_transaction.splitCount() < 2) {
-      category->completion()->setSelected(QString());
+      if (category && category->completion()) {
+        category->completion()->setSelected(QString());
+      }
     } else {
       foreach (const auto split, d->m_transaction.splits()) {
         if (split == d->m_split)
@@ -1236,7 +1238,7 @@ bool StdTransactionEditor::isComplete(QString& reason) const
       return false;
     }
     postDate->markAsBadDate();
-    postDate->setToolTip("");
+    postDate->setToolTip(QString());
   }
 
   for (it_w = d->m_editWidgets.begin(); it_w != d->m_editWidgets.end(); ++it_w) {
@@ -1384,8 +1386,16 @@ int StdTransactionEditor::slotEditSplits()
 
       if ((rc = dlg->exec()) == QDialog::Accepted) {
         d->m_transaction = dlg->transaction();
-        if (!d->m_transaction.splits().isEmpty())
+        if (!d->m_transaction.splits().isEmpty()) {
           d->m_split = d->m_transaction.splits().front();
+          // if we have only two splits left, we copy the memo
+          // of the second (data from the split editor) to the
+          // first (data used in the transaction editor)
+          if (d->m_transaction.splitCount() == 2) {
+            d->m_split.setMemo(d->m_transaction.splits().last().memo());
+            d->m_transaction.modifySplit(d->m_split);
+          }
+        }
         loadEditWidgets();
       }
 
