@@ -39,6 +39,7 @@
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #include <QTemporaryFile>
+#include <QFileInfo>
 
 // ----------------------------------------------------------------------------
 // KDE Headers
@@ -132,7 +133,7 @@ const char* homePageItems[] = {
   I18N_NOOP("Favorite reports"),
   I18N_NOOP("Forecast (schedule)"),
   I18N_NOOP("Net worth forecast"),
-  I18N_NOOP("Forecast (history)"),
+  I18N_NOOP("Forecast (history)"),        // unused, s.a. KSettingsHome::slotLoadItems()
   I18N_NOOP("Assets and Liabilities"),
   I18N_NOOP("Budget"),
   I18N_NOOP("CashFlow"),
@@ -239,7 +240,7 @@ QString KMyMoneyUtils::findResource(QStandardPaths::StandardLocation type, const
     ///    mappings to the filename are not correct. This certainly must
     ///    be overhauled at some point in time (ipwizard, 2017-10-22)
     QString mask = filename.arg("_%1.%2");
-    rc = QStandardPaths::locate(type, mask.arg(country).arg(language));
+    rc = QStandardPaths::locate(type, mask.arg(country, language));
 
     // search the given resource
     if (rc.isEmpty()) {
@@ -298,10 +299,11 @@ KMyMoneyUtils::transactionTypeE KMyMoneyUtils::transactionType(const MyMoneyTran
     return SplitTransaction;
   }
   QString ida, idb;
-  if (t.splits().size() > 0)
-    ida = t.splits()[0].accountId();
-  if (t.splits().size() > 1)
-    idb = t.splits()[1].accountId();
+  const auto & splits = t.splits();
+  if (splits.size() > 0)
+    ida = splits[0].accountId();
+  if (splits.size() > 1)
+    idb = splits[1].accountId();
   if (ida.isEmpty() || idb.isEmpty())
     return Unknown;
 
@@ -375,7 +377,7 @@ QString KMyMoneyUtils::getAdjacentNumber(const QString& number, int offset)
     QString arg2 = exp.cap(2);
     QString arg3 = QString::number(exp.cap(3).toULong() + offset);
     QString arg4 = exp.cap(4);
-    num = QString("%1%2%3%4").arg(arg1).arg(arg2).arg(arg3).arg(arg4);
+    num = QString("%1%2%3%4").arg(arg1, arg2, arg3, arg4);
   } else {
     num = QStringLiteral("1");
   }
@@ -387,11 +389,11 @@ quint64 KMyMoneyUtils::numericPart(const QString & num)
   quint64 num64 = 0;
   QRegExp exp(QString("(.*\\D)?(0*)(\\d+)(\\D.*)?"));
   if (exp.indexIn(num) != -1) {
-    QString arg1 = exp.cap(1);
+    // QString arg1 = exp.cap(1);
     QString arg2 = exp.cap(2);
     QString arg3 = QString::number(exp.cap(3).toULongLong());
-    QString arg4 = exp.cap(4);
-    num64 = QString("%2%3").arg(arg2).arg(arg3).toULongLong();
+    // QString arg4 = exp.cap(4);
+    num64 = QString("%2%3").arg(arg2, arg3).toULongLong();
   }
   return num64;
 }
@@ -537,7 +539,8 @@ void KMyMoneyUtils::processPriceList(const MyMoneyStatement &st)
   QHash<QString, MyMoneySecurity> secBySymbol;
   QHash<QString, MyMoneySecurity> secByName;
 
-  for (const auto& sec : file->securityList()) {
+  const auto securityList = file->securityList();
+  for (const auto& sec : securityList) {
     secBySymbol[sec.tradingSymbol()] = sec;
     secByName[sec.name()] = sec;
   }
@@ -621,14 +624,20 @@ bool KMyMoneyUtils::fileExists(const QUrl &url)
 {
     bool fileExists = false;
     if (url.isValid()) {
-        short int detailLevel = 0; // Lowest level: file/dir/symlink/none
-        KIO::StatJob* statjob = KIO::stat(url, KIO::StatJob::SourceSide, detailLevel);
-        bool noerror = statjob->exec();
-        if (noerror) {
-            // We want a file
-            fileExists = !statjob->statResult().isDir();
+        if (url.isLocalFile() || url.scheme().isEmpty()) {
+          QFileInfo check_file(url.toLocalFile());
+          fileExists = check_file.exists() && check_file.isFile();
+
+        } else {
+            short int detailLevel = 0; // Lowest level: file/dir/symlink/none
+            KIO::StatJob* statjob = KIO::stat(url, KIO::StatJob::SourceSide, detailLevel);
+            bool noerror = statjob->exec();
+            if (noerror) {
+                // We want a file
+                fileExists = !statjob->statResult().isDir();
+            }
+            statjob->kill();
         }
-        statjob->kill();
     }
     return fileExists;
 }
@@ -730,7 +739,7 @@ void KMyMoneyUtils::newTag(const QString& newnameBase, QString& id)
       for (;;) {
         try {
           MyMoneyFile::instance()->tagByName(newname);
-          newname = QString::fromLatin1("%1 [%2]").arg(newnameBase, ++count);
+          newname = QString::fromLatin1("%1 [%2]").arg(newnameBase).arg(++count);
         } catch (const MyMoneyException &) {
           break;
         }
