@@ -99,7 +99,7 @@ protected:
   int visibleItems(const QModelIndex& index) const;
 
 Q_SIGNALS:
-  void unusedIncomeExpenseAccountHidden() const;
+  void unusedIncomeExpenseAccountHidden();
 
 private:
   Q_DECLARE_PRIVATE(AccountsProxyModel)
