@@ -1,19 +1,21 @@
-/***************************************************************************
-                          mymoneyschedule.h
-                             -------------------
-    copyright            : (C) 2000-2002 by Michael Edwardes <mte@users.sourceforge.net>
-                           (C) 2007 by Thomas Baumgart <ipwizard@users.sourceforge.net>
-
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2000-2004  Michael Edwardes <mte@users.sourceforge.net>
+ * Copyright 2002-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2005       Ace Jones <acejones@users.sourceforge.net>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef MYMONEYSCHEDULE_H
 #define MYMONEYSCHEDULE_H
@@ -68,6 +70,7 @@ public:
     * Standard constructor
     */
   MyMoneySchedule();
+  explicit MyMoneySchedule(const QString &id);
 
   /**
     * Constructor for initialising the object.
@@ -87,8 +90,6 @@ public:
                            bool fixed,
                            bool autoEnter);
 
-  explicit MyMoneySchedule(const QDomElement& node);
-
   MyMoneySchedule(const QString& id,
                   const MyMoneySchedule& other);
 
@@ -103,11 +104,12 @@ public:
   ~MyMoneySchedule();
 
   /**
-    * Simple get method that returns the occurrence frequency.
+    * Simple get method that returns the base occurrence frequency.
     *
-    * @return eMyMoney::Schedule::Occurrence The instance frequency.
+    * @return eMyMoney::Schedule::Occurrence The instance frequency
+    *         reduced to the simple units.
     */
-  eMyMoney::Schedule::Occurrence occurrence() const;
+  eMyMoney::Schedule::Occurrence baseOccurrence() const;
 
   /**
     * Simple get method that returns the occurrence period
@@ -116,7 +118,7 @@ public:
     * @return eMyMoney::Schedule::Occurrence The instance period
     *
     */
-  eMyMoney::Schedule::Occurrence occurrencePeriod() const;
+  eMyMoney::Schedule::Occurrence occurrence() const;
 
   /**
     * Simple get method that returns the occurrence period multiplier.
@@ -210,6 +212,18 @@ public:
     */
   MyMoneyTransaction transaction() const;
 
+  /**
+    * Simple method that sets the transaction for the schedule.
+    * The transaction must have a valid postDate set, otherwise
+    * it will not be accepted. This test is bypassed, if @a noDateCheck
+    * is set to true
+    *
+    * @param transaction The new transaction.
+    * @param noDateCheck if @a true, the date check is bypassed
+    * @return none
+    */
+  void setTransaction(const MyMoneyTransaction& transaction, bool noDateCheck);
+
   /**
     * Simple method that returns the schedules last payment. If the
     * schedule has never been executed, QDate() will be returned.
@@ -495,8 +509,6 @@ public:
   void recordPayment(const QDate&);
   QList<QDate> recordedPayments() const;
 
-  void writeXML(QDomDocument& document, QDomElement& parent) const;
-
   /**
     * This method checks if a reference to the given object exists. It returns,
     * a @p true if the object is referencing the one requested by the
@@ -506,7 +518,7 @@ public:
     * @retval true This object references object with id @p id.
     * @retval false This object does not reference the object with id @p id.
     */
-  virtual bool hasReferenceTo(const QString& id) const;
+  virtual bool hasReferenceTo(const QString& id) const final override;
 
   /**
    * This method replaces all occurrences of id @a oldId with
@@ -660,18 +672,6 @@ private:
     */
   void fixDate(QDate& date) const;
 
-  /**
-    * Simple method that sets the transaction for the schedule.
-    * The transaction must have a valid postDate set, otherwise
-    * it will not be accepted. This test is bypassed, if @a noDateCheck
-    * is set to true
-    *
-    * @param transaction The new transaction.
-    * @param noDateCheck if @a true, the date check is bypassed
-    * @return none
-    */
-  void setTransaction(const MyMoneyTransaction& transaction, bool noDateCheck);
-
   /**
     * This method adds a number of Half Months to the given Date.
     * This is used for EveryHalfMonth occurrences.
