@@ -669,21 +669,20 @@ void MyMoneyStorageMgr::modifyTransaction(const MyMoneyTransaction& transaction)
   if (it_t == d->m_transactionList.end())
     throw MYMONEYEXCEPTION_CSTRING("invalid transaction key");
 
-  foreach (const auto split, (*it_t).splits()) {
-    auto acc = d->m_accountList[split.accountId()];
-    // we only need to adjust non-investment accounts here
-    // as for investment accounts the balance will be recalculated
-    // after the transaction has been added.
-    if (!acc.isInvest()) {
-      d->adjustBalance(acc, split, true);
-      acc.touch();
-      d->m_accountList.modify(acc.id(), acc);
-    }
-  }
+  // keep a copy before we remove the transaction from the pool
+  const auto oldTransaction = (*it_t);
 
   // remove old transaction from lists
   d->m_transactionList.remove(oldKey);
 
+  // and adjust the balances of the accounts
+  foreach (const auto split, oldTransaction.splits()) {
+    auto acc = d->m_accountList[split.accountId()];
+    d->adjustBalance(acc, split, true);
+    acc.touch();
+    d->m_accountList.modify(acc.id(), acc);
+  }
+
   // add new transaction to lists
   QString newKey = transaction.uniqueSortKey();
   d->m_transactionList.insert(newKey, transaction);
@@ -855,9 +854,11 @@ void MyMoneyStorageMgr::transactionList(QList< QPair<MyMoneyTransaction, MyMoney
   Q_D(const MyMoneyStorageMgr);
   list.clear();
 
-  for (const auto& transaction : d->m_transactionList)
-    for (const auto& split : filter.matchingSplits(transaction))
+  for (const auto& transaction : d->m_transactionList) {
+    const auto& splits = filter.matchingSplits(transaction);
+    for (const auto& split : splits)
       list.append(qMakePair(transaction, split));
+  }
 }
 
 QList<MyMoneyTransaction> MyMoneyStorageMgr::transactionList(MyMoneyTransactionFilter& filter) const
@@ -1250,7 +1251,7 @@ QList<MyMoneySchedule> MyMoneyStorageMgr::scheduleList(const QString& accountId,
     }
 
     if (occurrence != eMyMoney::Schedule::Occurrence::Any) {
-      if (occurrence != (*pos).occurrence()) {
+      if (occurrence != (*pos).baseOccurrence()) {
         continue;
       }
     }
@@ -1340,7 +1341,7 @@ QList<MyMoneySchedule> MyMoneyStorageMgr::scheduleListEx(int scheduleTypes,
     if (scheduleTypes && !(scheduleTypes & (int)(*pos).type()))
       continue;
 
-    if (scheduleOcurrences && !(scheduleOcurrences & (int)(*pos).occurrence()))
+    if (scheduleOcurrences && !(scheduleOcurrences & (int)(*pos).baseOccurrence()))
       continue;
 
     if (schedulePaymentTypes && !(schedulePaymentTypes & (int)(*pos).paymentType()))
