@@ -40,7 +40,11 @@ using namespace test;
 QTEST_GUILESS_MAIN(MyMoneyTransactionFilterTest)
 
 
-// using namespace std;
+MyMoneyTransactionFilterTest::MyMoneyTransactionFilterTest::MyMoneyTransactionFilterTest()
+  : storage(nullptr)
+  , file(nullptr)
+{
+}
 
 void MyMoneyTransactionFilterTest::init()
 {
@@ -517,7 +521,7 @@ void MyMoneyTransactionFilterTest::testMatchTransactionTag()
   QVERIFY(filter.match(transaction));
   QCOMPARE(filter.matchingSplits(transaction).size(), 1);
 
-  // check no category support
+  // check disabled category splits support
   MyMoneySplit split4;
   split4.setAccountId(acExpenseId);
   split4.setShares(MyMoneyMoney(123.00));
@@ -531,7 +535,10 @@ void MyMoneyTransactionFilterTest::testMatchTransactionTag()
   QVERIFY(!filter.match(transaction2));
   QCOMPARE(filter.matchingSplits(transaction2).size(), 0);
 
-  qDebug() << "tags on categories could not be tested";
+  // check enabled category splits support
+  filter.setConsiderCategorySplits(true);
+  QVERIFY(filter.match(transaction2));
+  QCOMPARE(filter.matchingSplits(transaction2).size(), 1);
 }
 
 void MyMoneyTransactionFilterTest::testMatchTransactionTypeAllTypes()
