@@ -1,11 +1,10 @@
 /*
- * This file is part of KMyMoney, A Personal Finance Manager by KDE
- * Copyright (C) 2014 Christian Dávid <christian-david@web.de>
+ * Copyright 2013-2016  Christian Dávid <christian-david@web.de>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,7 +22,7 @@
 #include <QString>
 
 class MyMoneyFile;
-class IMyMoneyStorage;
+class MyMoneyStorageMgr;
 
 #define KMM_MYMONEY_UNIT_TESTABLE friend class onlineJobAdministrationTest;
 
@@ -31,9 +30,13 @@ class onlineJobAdministrationTest : public QObject
 {
   Q_OBJECT
 
-  IMyMoneyStorage* storage;
+  MyMoneyStorageMgr* storage;
   MyMoneyFile* file;
   QString accountId;
+
+public:
+  onlineJobAdministrationTest();
+
 private Q_SLOTS:
   void initTestCase();
   void cleanupTestCase();
