@@ -1,5 +1,8 @@
 /***************************************************************************
- *   Copyright 2009  Cristian Onet onet.cristian@gmail.com                 *
+ *   This file is part of KMyMoney, A Personal Finance Manager by KDE      *
+ *                                                                         *
+ *   Copyright (C) 2009      Cristian Onet <onet.cristian@gmail.com>       *
+ *   Copyright (C) 2019      Thomas Baumgart <tbaumgart@kde.org>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -27,12 +30,13 @@
 #include <QFile>
 #include <QDialog>
 #ifdef ENABLE_WEBENGINE
-#include <QWebEngineView>
+  #include <QWebEngineView>
 #else
-#include <KWebView>
+  #include <KWebView>
+#endif
+#ifdef IS_APPIMAGE
+  #include <QCoreApplication>
 #endif
-#include <QPrintDialog>
-#include <QPrinter>
 #include <QStandardPaths>
 
 // KDE includes
@@ -57,6 +61,8 @@
 #include "pluginsettings.h"
 #include "mymoneyenums.h"
 
+#include "kmm_printer.h"
+
 struct CheckPrinting::Private {
   QAction* m_action;
   QString  m_checkTemplateHTML;
@@ -65,13 +71,23 @@ struct CheckPrinting::Private {
 };
 
 CheckPrinting::CheckPrinting(QObject *parent, const QVariantList &args) :
-  KMyMoneyPlugin::Plugin(parent, "checkprinting"/*must be the same as X-KDE-PluginInfo-Name*/),
-  m_currentPrinter(nullptr)
+  KMyMoneyPlugin::Plugin(parent, "checkprinting"/*must be the same as X-KDE-PluginInfo-Name*/)
 {
   Q_UNUSED(args);
   // Tell the host application to load my GUI component
-  setComponentName("checkprinting", i18nc("It's about printing bank checks", "Check printing"));
-  setXMLFile("checkprinting.rc");
+  const auto componentName = QLatin1String("checkprinting");
+  const auto rcFileName = QLatin1String("checkprinting.rc");
+  setComponentName(componentName, i18nc("It's about printing bank checks", "Check printing"));
+
+#ifdef IS_APPIMAGE
+  const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+  setXMLFile(rcFilePath);
+
+  const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+  setLocalXMLFile(localRcFilePath);
+#else
+  setXMLFile(rcFileName);
+#endif
 
   // For ease announce that we have been loaded.
   qDebug("Plugins: checkprinting loaded");
@@ -187,27 +203,36 @@ void CheckPrinting::slotPrintCheck()
     checkHTML.replace("$PAYEE_CITY", file->payee((*it).split().payeeId()).city());
     checkHTML.replace("$PAYEE_POSTCODE", file->payee((*it).split().payeeId()).postcode());
     checkHTML.replace("$PAYEE_STATE", file->payee((*it).split().payeeId()).state());
-    checkHTML.replace("$AMOUNT_STRING", converter.convert((*it).split().shares().abs(), currency.smallestAccountFraction()));
-    checkHTML.replace("$AMOUNT_DECIMAL", MyMoneyUtils::formatMoney((*it).split().shares().abs(), currency));
+    checkHTML.replace("$AMOUNT_STRING", converter.convert((*it).split().value().abs(), currency.smallestAccountFraction()));
+    checkHTML.replace("$AMOUNT_DECIMAL", MyMoneyUtils::formatMoney((*it).split().value().abs(), currency));
     checkHTML.replace("$MEMO", (*it).split().memo());
+    const auto currencyId = (*it).transaction().commodity();
+    const auto accountcurrency = MyMoneyFile::instance()->currency(currencyId);
+    checkHTML.replace("$TRANSACTIONCURRENCY", accountcurrency.tradingSymbol());
+    int numSplits = (int)(*it).transaction().splitCount();
+    const int maxSplits = 11;
+    for (int i = maxSplits-1; i >= 0 ; i--) {
+        const QString valueVariable = QString("$SPLITVALUE%1").arg(i);
+        const QString accountVariable = QString("$SPLITACCOUNTNAME%1").arg(i);
+        if (i < numSplits) {
+            checkHTML.replace( valueVariable, MyMoneyUtils::formatMoney((*it).transaction().splits()[i].value().abs(), currency));
+            checkHTML.replace( accountVariable, (file->account((*it).transaction().splits()[i].accountId())).name());
+        } else {
+            checkHTML.replace( valueVariable, " ");
+            checkHTML.replace( accountVariable, " ");
+        }
+    }
 
     // print the check
     htmlPart->setHtml(checkHTML, QUrl("file://"));
-    m_currentPrinter = new QPrinter();
-    QPointer<QPrintDialog> dialog = new QPrintDialog(m_currentPrinter);
-    dialog->setWindowTitle(QString());
-    if (dialog->exec() != QDialog::Accepted) {
-      delete m_currentPrinter;
-      m_currentPrinter = nullptr;
-      continue;
-    } else {
+    auto printer = KMyMoneyPrinter::startPrint();
+    if (printer != nullptr) {
       #ifdef ENABLE_WEBENGINE
-        htmlPart->page()->print(m_currentPrinter, [=] (bool) {delete m_currentPrinter; m_currentPrinter = nullptr;});
+        htmlPart->page()->print(printer, [=] (bool) {});
       #else
-        htmlPart->print(m_currentPrinter);
+        htmlPart->print(printer);
       #endif
     }
-    delete dialog;
 
     // mark the transaction as printed
     markAsPrinted(*it);
