@@ -1,28 +1,32 @@
-/***************************************************************************
- *   Copyright 2009  Cristian Onet onet.cristian@gmail.com                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+ * Copyright 2009       Cristian Onet <onet.cristian@gmail.com>
+ * Copyright 2019       Thomas Baumgart <tbaumgart@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
+#include <config-kmymoney.h>
 #include "icalendarexporter.h"
 
+// Qt includes
 #include <QFileDialog>
 #include <QUrl>
 #include <QAction>
+#ifdef IS_APPIMAGE
+  #include <QCoreApplication>
+  #include <QStandardPaths>
+#endif
 
 // KDE includes
 #include <KPluginFactory>
@@ -55,8 +59,19 @@ iCalendarExporter::iCalendarExporter(QObject *parent, const QVariantList &args)
   d->m_iCalendarFileEntryName = "iCalendarFile";
 
   // Tell the host application to load my GUI component
-  setComponentName("icalendarexporter", i18n("iCalendar exporter"));
-  setXMLFile("icalendarexporter.rc");
+  const auto componentName = QLatin1String("icalendarexporter");
+  const auto rcFileName = QLatin1String("icalendarexporter.rc");
+  setComponentName(componentName, i18n("iCalendar exporter"));
+
+#ifdef IS_APPIMAGE
+  const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+  setXMLFile(rcFilePath);
+
+  const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+  setLocalXMLFile(localRcFilePath);
+#else
+  setXMLFile(rcFileName);
+#endif
 
   // For ease announce that we have been loaded.
   qDebug("Plugins: icalendarexporter loaded");
