@@ -33,13 +33,12 @@
 
 #include <KLocalizedString>
 
-// Prject Includes
+// Project Includes
 #include "kbankingsettings.h"
 
 chipTanDialog::chipTanDialog(QWidget* parent)
-  : QDialog(parent),
-    m_tan(""),
-    m_accepted(true)
+  : QDialog(parent)
+  , m_accepted(true)
 {
   ui.reset(new Ui::chipTanDialog);
   ui->setupUi(this);
@@ -164,7 +163,7 @@ void chipTanDialog::tanInputChanged(const QString& input)
     button->setToolTip(i18n("A valid tan is required to proceed."));
   } else {
     button->setEnabled(true);
-    button->setToolTip("");
+    button->setToolTip(QString());
   }
 }
 
