@@ -74,8 +74,8 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, KLineEdit* versionEdit, const QSt
     m_combo(combo),
     m_versionEdit(versionEdit)
 {
-// http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-intuit-products/
-// http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
+// https://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-intuit-products/
+// https://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
 
   // Quicken
   m_appMap[i18n("Quicken Windows 2003")] = "QWIN:1200";
@@ -94,6 +94,11 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, KLineEdit* versionEdit, const QSt
   // following two added as found in previous URL on 2017-10-01
   m_appMap[i18n("Quicken Windows 2015")] = "QWIN:2400";
   m_appMap[i18n("Quicken Windows 2016")] = "QWIN:2500";
+  // following three added as logical consequence on 2018-12-12
+  m_appMap[i18n("Quicken Windows 2017")] = "QWIN:2600";
+  m_appMap[i18n("Quicken Windows 2018")] = "QWIN:2700";
+  m_appMap[i18n("Quicken Windows 2019")] = "QWIN:2800";
+  // the swiss army knife entry :)
   m_appMap[i18n("Quicken Windows (Expert)")] = "QWIN:";
 
   // MS-Money
@@ -328,8 +333,8 @@ void MyMoneyOfxConnector::initRequest(OfxFiLogin* fi) const
 #endif
 
   // If we don't know better, we pretend to be Quicken 2008
-  // http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-intuit-products/
-  // http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
+  // https://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-intuit-products/
+  // https://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
   QString appId = m_account.onlineBankingSettings().value("appId");
   QRegExp exp("(.*):(.*)");
   if (exp.indexIn(appId) != -1) {
