@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config-kmymoney.h>
 #include "ofximporter.h"
 
 // ----------------------------------------------------------------------------
@@ -26,6 +27,10 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QByteArray>
+#ifdef IS_APPIMAGE
+  #include <QCoreApplication>
+  #include <QStandardPaths>
+#endif
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -125,8 +130,20 @@ OFXImporter::OFXImporter(QObject *parent, const QVariantList &args) :
     d(new Private)
 {
   Q_UNUSED(args)
-  setComponentName(QStringLiteral("ofximporter"), i18n("OFX Importer"));
-  setXMLFile(QStringLiteral("ofximporter.rc"));
+  const auto componentName = QLatin1String("ofximporter");
+  const auto rcFileName = QLatin1String("ofximporter.rc");
+  setComponentName(componentName, i18n("OFX Importer"));
+
+#ifdef IS_APPIMAGE
+  const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+  setXMLFile(rcFilePath);
+
+  const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+  setLocalXMLFile(localRcFilePath);
+#else
+  setXMLFile(rcFileName);
+#endif
+
   createActions();
 
   // For ease announce that we have been loaded.
@@ -658,7 +675,10 @@ int OFXImporter::ofxAccountCallback(struct OfxAccountData data, void * pv)
   }
 
   // ask KMyMoney for an account id
-  s.m_accountId = pofx->account(QStringLiteral("kmmofx-acc-ref"), QString("%1-%2").arg(s.m_strRoutingNumber, s.m_strAccountNumber)).id();
+  // but only if we have any information to ask for
+  if (!s.m_strAccountNumber.isEmpty() || !s.m_strRoutingNumber.isEmpty()) {
+    s.m_accountId = pofx->account(QStringLiteral("kmmofx-acc-ref"), QString("%1-%2").arg(s.m_strRoutingNumber, s.m_strAccountNumber)).id();
+  }
 
   // copy over the securities
   s.m_listSecurities = pofx->d->m_securitylist;
