@@ -274,12 +274,24 @@ void QueryTable::constructTotalRows()
   if (m_rows.isEmpty())
     return;
 
-  // qSort places grand total at last position, because it doesn't belong to any group
-  for (int i = 0; i < m_rows.count(); ++i) {
-    if (m_rows.at(0)[ctRank] == QLatin1String("4") || m_rows.at(0)[ctRank] == QLatin1String("5")) // it should be unlikely that total row is at the top of rows, so...
-      m_rows.move(0, m_rows.count() - 1 - i);                       // ...move it at the bottom
-    else
-      break;
+  // qSort places grand total at first positions, because it doesn't belong to any group
+  // subtotals are placed in front of the topAccount rows
+  const auto rows = m_rows.count();
+  for (int i = 0; i < rows-1; ++i) {
+    // it should be unlikely that total row is at the top of rows, so...
+    if ((m_rows.at(i)[ctRank] == QLatin1String("5")) || (m_rows.at(i)[ctTopAccount].isEmpty())) {
+      m_rows.move(i, rows - 1);                       // ...move it at the end
+      --i; // check the same slot again
+    } else if (m_rows.at(i)[ctRank] == QLatin1String("4")) {
+      // search last entry of same topAccount
+      auto last = i+1;
+      while ((m_rows.at(i)[ctTopAccount] == m_rows.at(last)[ctTopAccount]) && (last < (rows - 1))) {
+        ++last;
+      }
+      // move subtotal to last entry
+      m_rows.move(i, last - 1);                       // ...move to end of entries
+      i = last-1;
+    }
   }
 
   MyMoneyFile* file = MyMoneyFile::instance();
@@ -331,76 +343,84 @@ void QueryTable::constructTotalRows()
       totalCurrency[currencyID].last()[ctRowsCount] += MyMoneyMoney::ONE;
     }
 
-    // iterate over groups from the lowest to the highest to find group change
-    for (int i = groups.count() - 1; i >= 0 ; --i) {
-      // if any of groups from next row changes (or next row is the last row), then it's time to put totals row
-      if (lastRow || m_rows.at(iCurrentRow)[groups.at(i)] != m_rows.at(iNextRow)[groups.at(i)]) {
-        bool isMainCurrencyTotal = true;
-        QMap<QString, QList<QMap<cellTypeE, MyMoneyMoney>>>::iterator currencyGrp = totalCurrency.begin();
-        while (currencyGrp != totalCurrency.end()) {
-          if (!MyMoneyMoney((*currencyGrp).at(i + 1).value(ctRowsCount)).isZero()) {    // if no rows summed up, then no totals row
-            TableRow totalsRow;
-            // sum all subtotal values for higher groups (excluding grand total) and reset lowest group values
-            QMap<cellTypeE, MyMoneyMoney>::iterator upperGrp = (*currencyGrp)[i].begin();
-            QMap<cellTypeE, MyMoneyMoney>::iterator lowerGrp = (*currencyGrp)[i + 1].begin();
-
-            while(upperGrp != (*currencyGrp)[i].end()) {
-              totalsRow[lowerGrp.key()] = lowerGrp.value().toString();  // fill totals row with subtotal values...
-              (*upperGrp) += (*lowerGrp);
-              //          (*lowerGrp) = MyMoneyMoney();
-              ++upperGrp;
-              ++lowerGrp;
-            }
-
-            // custom total values calculations
-            foreach (auto subtotal, subtotals) {
-              if (subtotal == ctReturnInvestment)
-                totalsRow[subtotal] = helperROI((*currencyGrp).at(i + 1).value(ctBuys) - (*currencyGrp).at(i + 1).value(ctReinvestIncome), (*currencyGrp).at(i + 1).value(ctSells),
-                                                (*currencyGrp).at(i + 1).value(ctStartingBalance), (*currencyGrp).at(i + 1).value(ctEndingBalance) + (*currencyGrp).at(i + 1).value(ctMarketValue),
-                                                (*currencyGrp).at(i + 1).value(ctCashIncome));
-              else if (subtotal == ctPercentageGain) {
-                const MyMoneyMoney denominator = (*currencyGrp).at(i + 1).value(ctBuys).abs();
-                totalsRow[subtotal] = denominator.isZero() ? QString():
-                    (((*currencyGrp).at(i + 1).value(ctBuys) + (*currencyGrp).at(i + 1).value(ctMarketValue)) / denominator).toString();
-              } else if (subtotal == ctPrice)
-                totalsRow[subtotal] = MyMoneyMoney((*currencyGrp).at(i + 1).value(ctPrice) / (*currencyGrp).at(i + 1).value(ctRowsCount)).toString();
-            }
-
-            // total values that aren't calculated here, but are taken untouched from external source, e.g. constructPerformanceRow
-            if (!stashedTotalRows.isEmpty()) {
-              for (int j = 0; j < stashedTotalRows.count(); ++j) {
-                if (stashedTotalRows.at(j).value(ctCurrency) != currencyID)
-                  continue;
-                foreach (auto subtotal, subtotals) {
-                  if (subtotal == ctReturn)
-                    totalsRow[ctReturn] = stashedTotalRows.takeAt(j)[ctReturn];
-                }
-                break;
-              }
-            }
-
-            (*currencyGrp).replace(i + 1, totalsValues);
-            for (int j = 0; j < groups.count(); ++j) {
-              totalsRow[groups.at(j)] = m_rows.at(iCurrentRow)[groups.at(j)];   // ...and identification
-            }
-
-            currencyID = currencyGrp.key();
-            if (currencyID.isEmpty() && totalCurrency.count() > 1)
-              currencyID = file->baseCurrency().id();
-            totalsRow[ctCurrency] = currencyID;
-            if (isMainCurrencyTotal) {
-              totalsRow[ctRank] = QLatin1Char('4');
-              isMainCurrencyTotal = false;
-            } else
-              totalsRow[ctRank] = QLatin1Char('5');
-            totalsRow[ctDepth] = QString::number(i);
-            totalsRow.remove(ctRowsCount);
-
-            m_rows.insert(iNextRow++, totalsRow);  // iCurrentRow and iNextRow can diverge here by more than one
-          }
-          ++currencyGrp;
+    auto levelToClose = groups.count();
+    if (!lastRow) {
+      for (int i = 0; i < groups.count(); ++i) {
+        if (m_rows.at(iCurrentRow)[groups.at(i)] != m_rows.at(iNextRow)[groups.at(i)]) {
+          levelToClose = i;
+          break;
         }
       }
+    } else {
+      levelToClose = 0;   // all, we're done
+    }
+    // iterate over groups from the lowest to the highest to close groups
+    for (int i = groups.count() - 1; i >= levelToClose ; --i) {
+      bool isMainCurrencyTotal = true;
+      QMap<QString, QList<QMap<cellTypeE, MyMoneyMoney>>>::iterator currencyGrp = totalCurrency.begin();
+      while (currencyGrp != totalCurrency.end()) {
+        if (!MyMoneyMoney((*currencyGrp).at(i + 1).value(ctRowsCount)).isZero()) {    // if no rows summed up, then no totals row
+          TableRow totalsRow;
+          // sum all subtotal values for higher groups (excluding grand total) and reset lowest group values
+          QMap<cellTypeE, MyMoneyMoney>::iterator upperGrp = (*currencyGrp)[i].begin();
+          QMap<cellTypeE, MyMoneyMoney>::iterator lowerGrp = (*currencyGrp)[i + 1].begin();
+
+          while(upperGrp != (*currencyGrp)[i].end()) {
+            totalsRow[lowerGrp.key()] = lowerGrp.value().toString();  // fill totals row with subtotal values...
+            (*upperGrp) += (*lowerGrp);
+            //          (*lowerGrp) = MyMoneyMoney();
+            ++upperGrp;
+            ++lowerGrp;
+          }
+
+          // custom total values calculations
+          foreach (auto subtotal, subtotals) {
+            if (subtotal == ctReturnInvestment)
+              totalsRow[subtotal] = helperROI((*currencyGrp).at(i + 1).value(ctBuys) - (*currencyGrp).at(i + 1).value(ctReinvestIncome), (*currencyGrp).at(i + 1).value(ctSells),
+                                              (*currencyGrp).at(i + 1).value(ctStartingBalance), (*currencyGrp).at(i + 1).value(ctEndingBalance) + (*currencyGrp).at(i + 1).value(ctMarketValue),
+                                              (*currencyGrp).at(i + 1).value(ctCashIncome));
+            else if (subtotal == ctPercentageGain) {
+              const MyMoneyMoney denominator = (*currencyGrp).at(i + 1).value(ctBuys).abs();
+              totalsRow[subtotal] = denominator.isZero() ? QString():
+                  (((*currencyGrp).at(i + 1).value(ctBuys) + (*currencyGrp).at(i + 1).value(ctMarketValue)) / denominator).toString();
+            } else if (subtotal == ctPrice)
+              totalsRow[subtotal] = MyMoneyMoney((*currencyGrp).at(i + 1).value(ctPrice) / (*currencyGrp).at(i + 1).value(ctRowsCount)).toString();
+          }
+
+          // total values that aren't calculated here, but are taken untouched from external source, e.g. constructPerformanceRow
+          if (!stashedTotalRows.isEmpty()) {
+            for (int j = 0; j < stashedTotalRows.count(); ++j) {
+              if (stashedTotalRows.at(j).value(ctCurrency) != currencyID)
+                continue;
+              foreach (auto subtotal, subtotals) {
+                if (subtotal == ctReturn)
+                  totalsRow[ctReturn] = stashedTotalRows.takeAt(j)[ctReturn];
+              }
+              break;
+            }
+          }
+
+          (*currencyGrp).replace(i + 1, totalsValues);
+          for (int j = 0; j < groups.count(); ++j) {
+            totalsRow[groups.at(j)] = m_rows.at(iCurrentRow)[groups.at(j)];   // ...and identification
+          }
+
+          currencyID = currencyGrp.key();
+          if (currencyID.isEmpty() && totalCurrency.count() > 1)
+            currencyID = file->baseCurrency().id();
+          totalsRow[ctCurrency] = currencyID;
+          if (isMainCurrencyTotal) {
+            totalsRow[ctRank] = QLatin1Char('4');
+            isMainCurrencyTotal = false;
+          } else
+            totalsRow[ctRank] = QLatin1Char('5');
+          totalsRow[ctDepth] = QString::number(i);
+          totalsRow.remove(ctRowsCount);
+
+          m_rows.insert(iNextRow++, totalsRow);  // iCurrentRow and iNextRow can diverge here by more than one
+        }
+        ++currencyGrp;
+      }
     }
 
     // code to put grand total row
@@ -455,7 +475,7 @@ void QueryTable::constructTotalRows()
       }
       break;                                      // no use to loop further
     }
-    iCurrentRow = iNextRow;                             // iCurrent makes here a leap forward by at least one
+    iCurrentRow = iNextRow;                       // iCurrent makes here a leap forward by at least one
   }
 }
 
@@ -479,17 +499,20 @@ void QueryTable::constructTransactionTable()
     case eMyMoney::Report::RowType::Category:
     case eMyMoney::Report::RowType::TopCategory:
       use_summary = false;
-      use_transfers = false;
+      use_transfers = report.isIncludingTransfers();
+      report.setTreatTransfersAsIncomeExpense(use_transfers);
       hide_details = false;
       break;
     case eMyMoney::Report::RowType::Payee:
       use_summary = false;
-      use_transfers = false;
+      use_transfers = report.isIncludingTransfers();
+      report.setTreatTransfersAsIncomeExpense(use_transfers);
       hide_details = (m_config.detailLevel() == eMyMoney::Report::DetailLevel::None);
       break;
     case eMyMoney::Report::RowType::Tag:
       use_summary = false;
-      use_transfers = false;
+      use_transfers = report.isIncludingTransfers();
+      report.setTreatTransfersAsIncomeExpense(use_transfers);
       hide_details = (m_config.detailLevel() == eMyMoney::Report::DetailLevel::None);
       tag_special_case = true;
       break;
@@ -548,7 +571,10 @@ void QueryTable::constructTransactionTable()
         myBegin = it_split;
 
       if ((myBegin == splits.end()) && ! splitAcc.isIncomeExpense()) {
-        myBegin = it_split;
+        // continue if split references an unselected account
+        if (report.includesAccount(splitAcc.id())) {
+          myBegin = it_split;
+        }
       }
     }
 
@@ -641,7 +667,9 @@ void QueryTable::constructTransactionTable()
       else
         xr = MyMoneyMoney::ONE;
 
-      if (it_split == myBegin) {
+      qA[ctTag].clear();
+
+      if (it_split == myBegin && splits.count() > 1) {
         include_me = m_config.includes(splitAcc);
         if (include_me)
           // track accts that will need opening and closing balances
@@ -766,7 +794,6 @@ void QueryTable::constructTransactionTable()
               qA[ctCategory] = i18n("[Split Transaction]");
               qA[ctTopCategory] = i18nc("Split transaction", "Split");
               qA[ctCategoryType] = i18nc("Split transaction", "Split");
-
               m_rows += qA;
             }
           }
@@ -817,12 +844,20 @@ void QueryTable::constructTransactionTable()
               //convert to lowest fraction
               qA[ctSplit] = (-(*it_split).shares() * xr).convert(fraction).toString();
               qA[ctRank] = QLatin1Char('2');
+              qA[ctTag] = "";
+              QString delimiter = "";
+              for (int i = 0; i < tagIdList.size(); i++) {
+                qA[ctTag] += delimiter + file->tag(tagIdList[i]).name().simplified();
+                delimiter = ", ";
+              }
             } else {
               //this applies when the transaction has only 2 splits, or each split is going to be
               //shown separately, eg. transactions by category
               switch (m_config.rowType()) {
                 case eMyMoney::Report::RowType::Category:
                 case eMyMoney::Report::RowType::TopCategory:
+                case eMyMoney::Report::RowType::Tag:
+                case eMyMoney::Report::RowType::Payee:
                   if (splitAcc.isIncomeExpense())
                     qA[ctValue] = (-(*it_split).shares() * xr).convert(fraction).toString(); // needed for category reports, in case of multicurrency transaction it breaks it
                   break;
@@ -854,26 +889,29 @@ void QueryTable::constructTransactionTable()
               qA [ctCategoryType] = MyMoneyAccount::accountTypeToString(splitAcc.accountGroup());
             }
 
-            if (use_transfers || (splitAcc.isIncomeExpense() && m_config.includes(splitAcc))) {
-              //if it matches the text of the main split of the transaction or
-              //it matches this particular split, include it
-              //otherwise, skip it
-              //if the filter is "does not contain" exclude the split if it does not match
-              //even it matches the whole split
-              if ((m_config.isInvertingText() &&
-                   m_config.match((*it_split)))
-                  || (!m_config.isInvertingText()
-                      && (transaction_text
-                          || m_config.match((*it_split))))) {
-                if (tag_special_case) {
-                  if (!tagIdListCache.size())
-                    qA[ctTag] = i18n("[No Tag]");
-                  else
-                    for (int i = 0; i < tagIdListCache.size(); i++) {
-                      qA[ctTag] = file->tag(tagIdListCache[i]).name().simplified();
-                      m_rows += qA;
+            if (splits.count() > 1) {
+              if (use_transfers || (splitAcc.isIncomeExpense() && m_config.includes(splitAcc))) {
+                //if it matches the text of the main split of the transaction or
+                //it matches this particular split, include it
+                //otherwise, skip it
+                //if the filter is "does not contain" exclude the split if it does not match
+                //even it matches the whole split
+                if ((m_config.isInvertingText() &&
+                    m_config.match((*it_split)))
+                    || (!m_config.isInvertingText()
+                        && (transaction_text
+                            || m_config.match((*it_split))))) {
+                  if (tag_special_case) {
+                    if (tagIdListCache.isEmpty()) {
+                      qA[ctTag] = i18n("[No Tag]");
+                    } else {
+                      QString delimiter;
+                      foreach(const auto tagId, tagIdListCache) {
+                        qA[ctTag] += delimiter + file->tag(tagId).name().simplified();
+                        delimiter = QLatin1Char(',');
+                      }
                     }
-                } else {
+                  }
                   m_rows += qA;
                 }
               }
@@ -881,8 +919,8 @@ void QueryTable::constructTransactionTable()
           }
         }
 
-        if (m_config.includes(splitAcc) && use_transfers &&
-            !(splitAcc.isInvest() && include_me)) { // otherwise stock split is displayed twice in report
+        if ((m_config.includes(splitAcc) && use_transfers &&
+            !(splitAcc.isInvest() && include_me)) || splits.count() == 1) { // otherwise stock split is displayed twice in report
           if (! splitAcc.isIncomeExpense()) {
             //multiply by currency and convert to lowest fraction
             qS[ctValue] = ((*it_split).shares() * xr).convert(fraction).toString();
@@ -893,10 +931,13 @@ void QueryTable::constructTransactionTable()
             qS[ctAccountID] = splitAcc.id();
             qS[ctTopAccount] = splitAcc.topParentName();
 
-            qS[ctCategory] = ((*it_split).shares().isNegative())
-                             ? i18n("Transfer to %1", a_fullname)
-                             : i18n("Transfer from %1", a_fullname);
-
+            if (splits.count() > 1) {
+              qS[ctCategory] = ((*it_split).shares().isNegative())
+                              ? i18n("Transfer to %1", a_fullname)
+                              : i18n("Transfer from %1", a_fullname);
+            } else {
+              qS[ctCategory] = i18n("*** UNASSIGNED ***");
+            }
             qS[ctInstitution] = institution.isEmpty()
                                 ? i18n("No Institution")
                                 : file->institution(institution).name();
@@ -906,10 +947,14 @@ void QueryTable::constructTransactionTable()
                          : (*it_split).memo();
 
             //FIXME-ALEX When is used this? I can't find in which condition we arrive here... maybe this code is useless?
-            QString delimiter;
-            for (int i = 0; i < tagIdList.size(); i++) {
-              qA[ctTag] += delimiter + file->tag(tagIdList[i]).name().simplified();
-              delimiter = '+';
+            if (tagIdList.isEmpty()) {
+              qS[ctTag] = i18n("[No Tag]");
+            } else {
+              QString delimiter;
+              foreach(const auto tagId, tagIdList) {
+                qS[ctTag] += delimiter + file->tag(tagId).name().simplified();
+                delimiter = QLatin1Char(',');
+              }
             }
 
             qS[ctPayee] = payee.isEmpty()
