@@ -823,10 +823,14 @@ public:
       if (statement) {
         const QString aboutDeposits = i18np("%1 deposit (%2)", "%1 deposits (%2)",
                                             deposits[m_currentAccount.id()], depositAmount[m_currentAccount.id()].abs().formatMoney(m_currentAccount.fraction()));
+        const QString aboutCharges = i18np("%1 charge (%2)", "%1 charges (%2)",
+                                           deposits[m_currentAccount.id()], depositAmount[m_currentAccount.id()].abs().formatMoney(m_currentAccount.fraction()));
         const QString aboutPayments = i18np("%1 payment (%2)", "%1 payments (%2)",
                                             payments[m_currentAccount.id()], paymentAmount[m_currentAccount.id()].abs().formatMoney(m_currentAccount.fraction()));
 
-        statement->setText(i18nc("%1 is a string, e.g. 7 deposits; %2 is a string, e.g. 4 payments", "%1, %2", aboutDeposits, aboutPayments));
+        statement->setText(i18nc("%1 is a string, e.g. 7 deposits; %2 is a string, e.g. 4 payments", "%1, %2",
+                                 m_currentAccount.accountType() == eMyMoney::Account::Type::CreditCard ? aboutCharges : aboutDeposits,
+                                 aboutPayments));
       }
       if (pStatement) {
         pStatement->setText(i18np("%1 payment (%2)", "%1 payments (%2)", payments[m_currentAccount.id()]
@@ -844,7 +848,9 @@ public:
       // make sure to use the value specified in the option during reconciliation
       if (isReconciliationAccount())
         split.setReconcileFlag(static_cast<eMyMoney::Split::State>(KMyMoneySettings::defaultReconciliationState()));
-      KMyMoneyRegister::Register::transactionFactory(m_register, MyMoneyTransaction(), split, 0);
+      MyMoneyTransaction emptyTransaction;
+      emptyTransaction.setCommodity(m_currentAccount.currencyId());
+      KMyMoneyRegister::Register::transactionFactory(m_register, emptyTransaction, split, 0);
 
       m_register->updateRegister(true);
 
@@ -1184,29 +1190,34 @@ public:
     try {
       it_t = list.begin();
       while (it_t != list.end()) {
+        const auto accountId = (*it_t).split().accountId();
+        const auto deletedNum = (*it_t).split().number();
+        const auto transactionId = (*it_t).transaction().id();
         // only remove those transactions that do not reference a closed account
         if (!file->referencesClosedAccount((*it_t).transaction())) {
           file->removeTransaction((*it_t).transaction());
           // remove all those references in the list of selected transactions
           // that refer to the same transaction we just removed so that we
           // will not be caught by an exception later on (see bko #285310)
-          KMyMoneyRegister::SelectedTransactions::iterator it_td = it_t;
-          ++it_td;
-          while (it_td != list.end()) {
-            if ((*it_t).transaction().id() == (*it_td).transaction().id()) {
-              it_td = list.erase(it_td);
+          while (it_t != list.end()) {
+            if (transactionId == (*it_t).transaction().id()) {
+              it_t = list.erase(it_t);
               i++; // bump count of deleted transactions
             } else {
-              ++it_td;
+              ++it_t;
             }
           }
+
+        } else {
+          list.erase(it_t);
         }
+        it_t = list.begin();
+
         // need to ensure "nextCheckNumber" is still correct
-        auto acc = file->account((*it_t).split().accountId());
+        auto acc = file->account(accountId);
 
         // the "lastNumberUsed" might have been the txn number deleted
         // so adjust it
-        QString deletedNum = (*it_t).split().number();
         if (deletedNum == acc.value("lastNumberUsed")) {
           // decrement deletedNum and set new "lastNumberUsed"
           QString num = KMyMoneyUtils::getAdjacentNumber(deletedNum, -1);
@@ -1214,11 +1225,10 @@ public:
           file->modifyAccount(acc);
         }
 
-        list.erase(it_t);
-        it_t = list.begin();
         emit q->slotStatusProgress(i++, 0);
       }
       ft.commit();
+
     } catch (const MyMoneyException &e) {
       KMessageBox::detailedSorry(q, i18n("Unable to delete transaction(s)"), e.what());
     }
@@ -1462,14 +1472,10 @@ public:
       const MyMoneyMoney &amount)
   {
     Q_Q(KGlobalLedgerView);
-    static const int NR_OF_STEPS_LIMIT = 300000;
+    static const int NR_OF_STEPS_LIMIT = 60000;
     static const int PROGRESSBAR_STEPS = 1000;
     QList<QPair<MyMoneyTransaction, MyMoneySplit> > result = transactions;
 
-//    KMSTATUS(i18n("Running automatic reconciliation"));
-    auto progressBarIndex = 0;
-    q->slotStatusProgress(progressBarIndex, NR_OF_STEPS_LIMIT / PROGRESSBAR_STEPS);
-
     // optimize the most common case - all transactions should be cleared
     QListIterator<QPair<MyMoneyTransaction, MyMoneySplit> > itTransactionSplitResult(result);
     MyMoneyMoney transactionsBalance;
@@ -1481,7 +1487,7 @@ public:
       result = transactions;
       return result;
     }
-    q->slotStatusProgress(progressBarIndex++, 0);
+
     // only one transaction is uncleared
     itTransactionSplitResult.toFront();
     int index = 0;
@@ -1493,7 +1499,6 @@ public:
       }
       index++;
     }
-    q->slotStatusProgress(progressBarIndex++, 0);
 
     // more than one transaction is uncleared - apply the algorithm
     result.clear();
@@ -1506,6 +1511,21 @@ public:
 
     QMap<MyMoneyMoney, QList<QPair<QString, QString> > > sumToComponentsMap;
 
+    struct restoreStatusMsgHelper {
+      restoreStatusMsgHelper(KGlobalLedgerView* qq)
+      : q(qq) {}
+
+      ~restoreStatusMsgHelper()
+      {
+        q->slotStatusMsg(QString());
+        q->slotStatusProgress(-1, -1);
+      }
+      KGlobalLedgerView* q;
+    } restoreHelper(q);
+
+    q->slotStatusMsg(i18n("Running automatic reconciliation"));
+    q->slotStatusProgress(0, NR_OF_STEPS_LIMIT);
+
     // compute the possible matches
     QListIterator<QPair<MyMoneyTransaction, MyMoneySplit> > it_ts(transactions);
     while (it_ts.hasNext()) {
@@ -1526,7 +1546,7 @@ public:
         sumToComponentsMap[transactionSplit.second.shares() + sum] = splitIds;
         int size = sumToComponentsMap.size();
         if (size % PROGRESSBAR_STEPS == 0) {
-          q->slotStatusProgress(progressBarIndex++, 0);
+          q->slotStatusProgress(size, 0);
         }
         if (size > NR_OF_STEPS_LIMIT) {
           return result; // it's taking too much resources abort the algorithm
@@ -1566,7 +1586,6 @@ public:
            qPrintable(MyMoneyUtils::formatMoney(amount, security)), sumToComponentsMap.size(), transactions.size());
   #endif
 
-    q->slotStatusProgress(-1, -1);
     return result;
   }
 
