@@ -58,7 +58,7 @@
 #include "mymoneyaccount.h"
 #include "mymoneymoney.h"
 #include "mymoneytransactionfilter.h"
-#include "kmymoneyglobalsettings.h"
+#include "kmymoneysettings.h"
 #include "kpayeereassigndlg.h"
 #include "models.h"
 #include "accountsmodel.h"
@@ -123,10 +123,14 @@ public:
     KMyMoneyViewBasePrivate(),
     q_ptr(qq),
     ui(new Ui::KPayeesView),
+    m_contact(nullptr),
+    m_payeeRow(0),
     m_needLoad(true),
+    m_searchWidget(nullptr),
     m_inSelection(false),
     m_allowEditing(true),
-    m_payeeFilterType(0)
+    m_payeeFilterType(0),
+    m_filterProxyModel(nullptr)
   {
   }
 
@@ -149,7 +153,7 @@ public:
 
     m_contact = new MyMoneyContact(q);
     m_filterProxyModel = new AccountNamesFilterProxyModel(q);
-    m_filterProxyModel->setHideEquityAccounts(!KMyMoneyGlobalSettings::expertMode());
+    m_filterProxyModel->setHideEquityAccounts(!KMyMoneySettings::expertMode());
     m_filterProxyModel->addAccountGroup(QVector<eMyMoney::Account::Type> {eMyMoney::Account::Type::Asset, eMyMoney::Account::Type::Liability, eMyMoney::Account::Type::Income, eMyMoney::Account::Type::Expense, eMyMoney::Account::Type::Equity});
 
     auto const model = Models::instance()->accountsModel();
@@ -158,10 +162,10 @@ public:
     m_filterProxyModel->sort((int)eAccountsModel::Column::Account);
     ui->comboDefaultCategory->setModel(m_filterProxyModel);
 
-    ui->matchTypeCombo->addItem(i18nc("@item No matching", "No matching"), MyMoneyPayee::matchDisabled);
-    ui->matchTypeCombo->addItem(i18nc("@item Match Payees name partially", "Match Payees name (partial)"), MyMoneyPayee::matchName);
-    ui->matchTypeCombo->addItem(i18nc("@item Match Payees name exactly", "Match Payees name (exact)"), MyMoneyPayee::matchNameExact);
-    ui->matchTypeCombo->addItem(i18nc("@item Search match in list", "Match on a name listed below"), MyMoneyPayee::matchKey);
+    ui->matchTypeCombo->addItem(i18nc("@item No matching", "No matching"), static_cast<int>(eMyMoney::Payee::MatchType::Disabled));
+    ui->matchTypeCombo->addItem(i18nc("@item Match Payees name partially", "Match Payees name (partial)"), static_cast<int>(eMyMoney::Payee::MatchType::Name));
+    ui->matchTypeCombo->addItem(i18nc("@item Match Payees name exactly", "Match Payees name (exact)"), static_cast<int>(eMyMoney::Payee::MatchType::NameExact));
+    ui->matchTypeCombo->addItem(i18nc("@item Search match in list", "Match on a name listed below"), static_cast<int>(eMyMoney::Payee::MatchType::Key));
 
     // create the searchline widget
     // and insert it into the existing layout
@@ -374,7 +378,7 @@ public:
     MyMoneySecurity base = file->baseCurrency();
 
     // setup sort order
-    ui->m_register->setSortOrder(KMyMoneyGlobalSettings::sortSearchView());
+    ui->m_register->setSortOrder(KMyMoneySettings::sortSearchView());
 
     // clear the register
     ui->m_register->clear();
@@ -392,7 +396,7 @@ public:
          ++it)
       filter.addPayee((*it).id());
 
-    filter.setDateFilter(KMyMoneyGlobalSettings::startDate().date(), QDate());
+    filter.setDateFilter(KMyMoneySettings::startDate().date(), QDate());
 
     // retrieve the list from the engine
     file->transactionList(m_transactionList, filter);
@@ -547,7 +551,7 @@ public:
         // then we create a new one
         try {
           newPayee = file->payee(payee_id);
-        } catch (const MyMoneyException &e) {
+        } catch (const MyMoneyException &) {
           if (type == KPayeeReassignDlg::TypeMerge) {
             // it's ok to use payee_id for both arguments since the first is const,
             // so it's garantee not to change its content
@@ -568,6 +572,18 @@ public:
             // loop over all splits
             for (auto& split : transaction.splits()) {
               // if the split is assigned to one of the selected payees, we need to modify it
+              if (split.isMatched()) {
+                auto tm = split.matchedTransaction();
+                for (auto& sm : tm.splits()) {
+                  if (payeeInList(m_selectedPayeesList, sm.payeeId())) {
+                    sm.setPayeeId(payee_id); // first modify payee in current split
+                    // then modify the split in our local copy of the transaction list
+                    tm.modifySplit(sm); // this does not modify the list object 'splits'!
+                  }
+                }
+                split.addMatch(tm);
+                transaction.modifySplit(split); // this does not modify the list object 'splits'!
+              }
               if (payeeInList(m_selectedPayeesList, split.payeeId())) {
                 split.setPayeeId(payee_id); // first modify payee in current split
                 // then modify the split in our local copy of the transaction list
@@ -601,8 +617,7 @@ public:
           }
 
         } catch (const MyMoneyException &e) {
-          KMessageBox::detailedSorry(q, i18n("Unable to reassign payee of transaction/split"),
-                                     i18n("%1 thrown in %2:%3", e.what(), e.file(), e.line()));
+          KMessageBox::detailedSorry(q, i18n("Unable to reassign payee of transaction/split"), e.what());
         }
       } else { // if !translist.isEmpty()
         if (type == KPayeeReassignDlg::TypeMerge) {
@@ -613,7 +628,7 @@ public:
 
       bool ignorecase;
       QStringList payeeNames;
-      MyMoneyPayee::payeeMatchType matchType = newPayee.matchData(ignorecase, payeeNames);
+      auto matchType = newPayee.matchData(ignorecase, payeeNames);
       QStringList deletedPayeeNames;
 
       // now loop over all selected payees and remove them
@@ -628,7 +643,7 @@ public:
       }
 
       // if we initially have no matching turned on, we just ignore the case (default)
-      if (matchType == MyMoneyPayee::matchDisabled)
+      if (matchType == eMyMoney::Payee::MatchType::Disabled)
         ignorecase = true;
 
       // update the destination payee if this was requested by the user
@@ -639,7 +654,7 @@ public:
         //       to the user himeself.
         QStringList::const_iterator it_n;
         for (it_n = deletedPayeeNames.constBegin(); it_n != deletedPayeeNames.constEnd(); ++it_n) {
-          if (matchType == MyMoneyPayee::matchKey) {
+          if (matchType == eMyMoney::Payee::MatchType::Key) {
             // make sure we really need it and it is not caught by an existing regexp
             QStringList::const_iterator it_k;
             for (it_k = payeeNames.constBegin(); it_k != payeeNames.constEnd(); ++it_k) {
@@ -655,7 +670,7 @@ public:
 
         // and update the payee in the engine context
         // make sure to turn on matching for this payee in the right mode
-        newPayee.setMatchData(MyMoneyPayee::matchKey, ignorecase, payeeNames);
+        newPayee.setMatchData(eMyMoney::Payee::MatchType::Key, ignorecase, payeeNames);
         file->modifyPayee(newPayee);
       }
       ft.commit();
@@ -664,8 +679,7 @@ public:
       m_selectedPayeesList.clear();
 
     } catch (const MyMoneyException &e) {
-      KMessageBox::detailedSorry(q, i18n("Unable to remove payee(s)"),
-                                 i18n("%1 thrown in %2:%3", e.what(), e.file(), e.line()));
+      KMessageBox::detailedSorry(q, i18n("Unable to remove payee(s)"), e.what());
     }
 
     return true;
