@@ -1,19 +1,20 @@
-/***************************************************************************
-                          ktagsview.cpp
-                          -------------
-    begin                : Sat Oct 13 2012
-    copyright            : (C) 2012 by Alessandro Russo <axela74@yahoo.it>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2012       Alessandro Russo <axela74@yahoo.it>
+ * Copyright 2017       Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "ktagsview.h"
 #include "ktagsview_p.h"
@@ -300,6 +301,7 @@ void KTagsView::showTransactions()
 
   // setup the list and the pointer vector
   MyMoneyTransactionFilter filter;
+  filter.setConsiderCategorySplits();
   filter.addTag(d->m_tag.id());
   filter.setDateFilter(KMyMoneySettings::startDate().date(), QDate());
 
@@ -399,21 +401,23 @@ void KTagsView::slotUpdateTag()
 
 void KTagsView::showEvent(QShowEvent* event)
 {
-  Q_D(KTagsView);
-  if (d->m_needLoad)
-    d->init();
+  if (MyMoneyFile::instance()->storageAttached()) {
+    Q_D(KTagsView);
+    if (d->m_needLoad)
+      d->init();
 
-  emit customActionRequested(View::Tags, eView::Action::AboutToShow);
+    emit customActionRequested(View::Tags, eView::Action::AboutToShow);
 
-  if (d->m_needsRefresh)
-    refresh();
+    if (d->m_needsRefresh)
+      refresh();
+
+    QList<MyMoneyTag> list;
+    selectedTags(list);
+    slotSelectTags(list);
+  }
 
   // don't forget base class implementation
   QWidget::showEvent(event);
-
-  QList<MyMoneyTag> list;
-  selectedTags(list);
-  slotSelectTags(list);
 }
 
 void KTagsView::updateTagActions(const QList<MyMoneyTag>& tags)
