@@ -69,7 +69,9 @@ class KEditLoanWizardPrivate : public KNewLoanWizardPrivate
 
 public:
   KEditLoanWizardPrivate(KEditLoanWizard *qq) :
-    KNewLoanWizardPrivate(qq)
+    KNewLoanWizardPrivate(qq),
+    m_lastSelection(0),
+    m_fullyRepayLoan(false)
   {
   }
 
@@ -145,7 +147,11 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
     d->ui->m_interestTypePage->ui->m_variableInterestButton->click();
   }
 
-  QString institutionName = file->institution(d->m_account.institutionId()).name();
+  QString institutionName;
+  try {
+    institutionName = file->institution(d->m_account.institutionId()).name();
+  } catch (const MyMoneyException &) {
+  }
   d->ui->m_loanAttributesPage->setInstitution(institutionName);
 
   MyMoneyMoney ir;
@@ -155,13 +161,13 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
     ir = d->m_account.interestRate(QDate::currentDate());
   }
   //FIXME: port
-  d->ui->m_interestPage->ui->m_interestRateEdit->loadText(ir.formatMoney(QString(), 3));
   d->ui->m_interestPage->ui->m_interestRateEdit->setPrecision(3);
-  d->ui->m_interestEditPage->ui->m_newInterestRateEdit->loadText(ir.formatMoney(QString(), 3));
+  d->ui->m_interestPage->ui->m_interestRateEdit->loadText(ir.formatMoney(QString(), 3));
   d->ui->m_interestEditPage->ui->m_newInterestRateEdit->setPrecision(3);
+  d->ui->m_interestEditPage->ui->m_newInterestRateEdit->loadText(ir.formatMoney(QString(), 3));
   d->ui->m_interestEditPage->ui->m_interestRateLabel->setText(QString(" ") + ir.formatMoney(QString(), 3) + QString("%"));
 
-  d->ui->m_paymentFrequencyPage->ui->m_paymentFrequencyUnitEdit->setCurrentIndex(d->ui->m_paymentFrequencyPage->ui->m_paymentFrequencyUnitEdit->findData(QVariant((int)d->m_schedule.occurrencePeriod()), Qt::UserRole, Qt::MatchExactly));
+  d->ui->m_paymentFrequencyPage->ui->m_paymentFrequencyUnitEdit->setCurrentIndex(d->ui->m_paymentFrequencyPage->ui->m_paymentFrequencyUnitEdit->findData(QVariant((int)d->m_schedule.occurrence()), Qt::UserRole, Qt::MatchExactly));
   d->ui->m_durationPage->updateTermWidgets(d->m_account.term());
 
   // the base payment (amortization and interest) is determined
@@ -207,7 +213,7 @@ void KEditLoanWizard::loadWidgets(const MyMoneyAccount& /* account */)
       d->m_transaction.addSplit(d->m_split);
     }
 
-    if (it_s.action() == MyMoneySplit::ActionInterest) {
+    if (it_s.action() == MyMoneySplit::actionName(eMyMoney::Split::Action::Interest)) {
       interestAccountId = it_s.accountId();
     }
 
@@ -413,7 +419,7 @@ bool KEditLoanWizard::validateCurrentPage()
             split = (*it).splitByAccount(m_account.id());
             balance += split.value();
 
-          } catch(const MyMoneyException &e) {
+          } catch (const MyMoneyException &e) {
             // account is not referenced within this transaction
           }
         }
@@ -465,9 +471,9 @@ void KEditLoanWizard::updateEditSummary()
     foreach (const MyMoneySplit& it_s, it.splits()) {
       // we only count those transactions that have an interest
       // and amortization part
-      if (it_s.action() == MyMoneySplit::ActionInterest)
+      if (it_s.action() == MyMoneySplit::actionName(eMyMoney::Split::Action::Interest))
         match |= 0x01;
-      if (it_s.action() == MyMoneySplit::ActionAmortization)
+      if (it_s.action() == MyMoneySplit::actionName(eMyMoney::Split::Action::Amortization))
         match |= 0x02;
     }
     if (match == 0x03)
@@ -503,9 +509,8 @@ const MyMoneyAccount KEditLoanWizard::account() const
 
   QString institution = d->ui->m_loanAttributesPage->ui->m_qcomboboxInstitutions->currentText();
   if (institution != i18n("(No Institution)")) {
-    QList<MyMoneyInstitution> list;
-    file->institutionList(list);
-    Q_FOREACH(const MyMoneyInstitution& testInstitution, list) {
+    const auto list = file->institutionList();
+    for (const auto& testInstitution : list) {
       if (testInstitution.name() == institution) {
         acc.setInstitutionId(testInstitution.id());
         break;
@@ -515,6 +520,7 @@ const MyMoneyAccount KEditLoanWizard::account() const
     acc.setInstitutionId(QString());
   }
 
+  acc.setName(d->ui->m_namePage->ui->m_nameEdit->text());
   acc.setFixedInterestRate(field("fixedInterestButton").toBool());
   acc.setFinalPayment(field("finalPaymentEdit").value<MyMoneyMoney>());
   acc.setTerm(d->ui->m_durationPage->term());
