@@ -37,18 +37,47 @@ cd $BUILD_PREFIX
 
 # Step 0: place the translations where ki18n and Qt look for them
 if [ -d $APPDIR/usr/share/locale ] ; then
-    mv $APPDIR/usr/share/locale $APPDIR/usr/share/kmymoney
+    mv -v $APPDIR/usr/share/locale $APPDIR/usr/share/kmymoney
+fi
+
+# Step 0a: Make sure our plugin directory already exists
+if [ ! -d $APPIMAGEPLUGINS ] ; then
+    mkdir -p $APPIMAGEPLUGINS
 fi
 
 # Step 1: Copy over all the resources provided by dependencies that we need
-cp -r $DEPS_INSTALL_PREFIX/share/locale $APPDIR/usr/share/kmymoney
-cp -r $DEPS_INSTALL_PREFIX/share/kf5 $APPDIR/usr/share
-cp -r $DEPS_INSTALL_PREFIX/share/mime $APPDIR/usr/share
-cp -r $DEPS_INSTALL_PREFIX/translations $APPDIR/usr/
-cp -r $DEPS_INSTALL_PREFIX/openssl/lib/*  $APPDIR/usr/lib
+cp -r -v $DEPS_INSTALL_PREFIX/share/locale $APPDIR/usr/share/kmymoney
+cp -r -v $DEPS_INSTALL_PREFIX/share/kf5 $APPDIR/usr/share
+cp -r -v $DEPS_INSTALL_PREFIX/share/kservices5 $APPDIR/usr/share
+cp -r -v $DEPS_INSTALL_PREFIX/share/mime $APPDIR/usr/share
+# cp -r -v $DEPS_INSTALL_PREFIX/translations $APPDIR/usr/
+cp -r -v $DEPS_INSTALL_PREFIX/openssl/lib/*  $APPDIR/usr/lib
+cp -r -v $DEPS_INSTALL_PREFIX/plugins/* $APPDIR/usr/plugins
+
+# @todo we still need the following program from /bin or /usr/bin:
+#  true, mount, umount (backup)
+#  cat (qif filter)
+
+# Step 1a: copy Gwenhywfar and AqBanking if they exist
+#          and make sure they find their translations
+cd $APPDIR/usr/share
+ln -s -v kmymoney/locale locale
+cd $BUILD_PREFIX
+
+for d in gwenhywfar aqbanking; do
+    echo "Try to locate $DEPS_INSTALL_PREFIX/lib/$d"
+    if [ -d $DEPS_INSTALL_PREFIX/lib/$d ]; then
+        echo "Copy $DEPS_INSTALL_PREFIX/lib/$d to $APPDIR/usr/bin/[lib,share]"
+        for sd in lib share; do
+            mkdir -p $APPDIR/usr/$sd
+            echo "tar -C $DEPS_INSTALL_PREFIX/$sd -cf - $d | tar -C $APPDIR/usr/$sd -xf -"
+            tar -C $DEPS_INSTALL_PREFIX/$sd -cf - $d | tar -C $APPDIR/usr/$sd -xf -
+        done
+    fi
+done
 
 # Step 2: Relocate x64 binaries from the architecture specific directory as required for Appimages
-mv $APPDIR/usr/lib/x86_64-linux-gnu/*  $APPDIR/usr/lib
+mv -v $APPDIR/usr/lib/x86_64-linux-gnu/*  $APPDIR/usr/lib
 rm -rf $APPDIR/usr/lib/x86_64-linux-gnu/
 
 # Step 3: Update the rpath in the various plugins we have to make sure they'll be loadable in an Appimage context
@@ -56,14 +85,8 @@ for lib in $PLUGINS/kmymoney/*.so*; do
   patchelf --set-rpath '$ORIGIN/../../lib' $lib;
 done
 
-# Step 4: Move plugins to loadable location in AppImage
-
-# Make sure our plugin directory already exists
-if [ ! -d $APPIMAGEPLUGINS ] ; then
-    mkdir -p $APPIMAGEPLUGINS
-fi
-
-mv $PLUGINS/* $APPIMAGEPLUGINS
+# Step 4: Copy plugins to loadable location in AppImage
+cp -r -v $PLUGINS/* $APPIMAGEPLUGINS
 
 # Step 5: Determine the version of KMyMoney we have just built
 # This is needed for linuxdeployqt/appimagetool to do the right thing
@@ -82,6 +105,9 @@ fi
 # Finally transition back to the build directory so we can build the appimage
 cd $BUILD_PREFIX
 
+# Remove everything that we do not need
+rm -rf $APPDIR/usr/include
+
 # Step 6: Build the image!!!
 linuxdeployqt $APPDIR/usr/share/applications/org.kde.kmymoney.desktop \
   -executable=$APPDIR/usr/bin/kmymoney \
